@@ -8,29 +8,43 @@
 
 
 
-.emmeans_prediction_data <- function(model, data_grid, cleaned_terms, ci.lvl, pmode, type, model_info, interval = NULL, model_data = NULL, ...) {
+.emmeans_prediction_data <- function(model,
+                                     data_grid,
+                                     cleaned_terms,
+                                     ci.lvl,
+                                     pmode,
+                                     type,
+                                     model_info,
+                                     interval = NULL,
+                                     model_data = NULL,
+                                     ...) {
   if (inherits(model, "MCMCglmm")) {
-    prediction_data <- .ggemmeans_predict_MCMCglmm(model, data_grid, cleaned_terms, ci.lvl, pmode, type, interval = interval, model_data = model_data, ...)
-  } else if (model_info$is_ordinal | model_info$is_multinomial | model_info$is_categorical) {
-    prediction_data <- .ggemmeans_predict_ordinal(model, data_grid, cleaned_terms, ci.lvl, type, interval = interval, model_data = model_data, ...)
+    prediction_data <- .ggemmeans_predict_MCMCglmm(
+      model, data_grid, cleaned_terms, ci.lvl, pmode, type,
+      interval = interval, model_data = model_data, ...
+    )
+  } else if (model_info$is_ordinal || model_info$is_multinomial || model_info$is_categorical) {
+    prediction_data <- .ggemmeans_predict_ordinal(
+      model, data_grid, cleaned_terms, ci.lvl, type,
+      interval = interval, model_data = model_data, ...
+    )
   } else if (inherits(model, c("gls", "lme"))) {
-    prediction_data <- .ggemmeans_predict_nlme(model, data_grid, cleaned_terms, ci.lvl, type, interval = interval, model_data = model_data, ...)
+    prediction_data <- .ggemmeans_predict_nlme(
+      model, data_grid, cleaned_terms, ci.lvl, type,
+      interval = interval, model_data = model_data, ...
+    )
   } else {
-    prediction_data <- .ggemmeans_predict_generic(model, data_grid, cleaned_terms, ci.lvl, pmode, type, interval = interval, model_data = model_data, ...)
+    prediction_data <- .ggemmeans_predict_generic(
+      model, data_grid, cleaned_terms, ci.lvl, pmode, type,
+      interval = interval, model_data = model_data, ...
+    )
   }
 }
 
 
 
-
-
-
-
-
 .ggemmeans_MixMod <- function(model, data_grid, cleaned_terms, ...) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package `emmeans` required to compute estimated marginal means for MixMod-models.", call. = FALSE)
-  }
+  insight::check_if_installed("emmeans", "to compute estimated marginal means for MixMod-models")
 
   x1 <- as.data.frame(suppressWarnings(emmeans::emmeans(
     model,
@@ -52,13 +66,8 @@
 
 
 
-
-
-
 .ggemmeans_glmmTMB <- function(model, data_grid, cleaned_terms, ...) {
-  if (!requireNamespace("emmeans")) {
-    stop("Package `emmeans` required to estimated marginal means effects for glmmTMB-models.", call. = FALSE)
-  }
+  insight::check_if_installed("emmeans", "to compute estimated marginal means for glmmTMB-models")
 
   x1 <- as.data.frame(suppressWarnings(emmeans::emmeans(
     model,
@@ -81,10 +90,14 @@
 
 
 
-
-
-
-.ggemmeans_predict_ordinal <- function(model, data_grid, cleaned_terms, ci.lvl, type, interval = NULL, model_data = NULL, ...) {
+.ggemmeans_predict_ordinal <- function(model,
+                                       data_grid,
+                                       cleaned_terms,
+                                       ci.lvl,
+                                       type,
+                                       interval = NULL,
+                                       model_data = NULL,
+                                       ...) {
   tmp <- emmeans::emmeans(
     model,
     specs = c(insight::find_response(model, combine = FALSE), cleaned_terms),
@@ -98,10 +111,15 @@
 
 
 
-
-
-
-.ggemmeans_predict_MCMCglmm <- function(model, data_grid, cleaned_terms, ci.lvl, pmode, type, interval = NULL, model_data = NULL, ...) {
+.ggemmeans_predict_MCMCglmm <- function(model,
+                                        data_grid,
+                                        cleaned_terms,
+                                        ci.lvl,
+                                        pmode,
+                                        type,
+                                        interval = NULL,
+                                        model_data = NULL,
+                                        ...) {
   tmp <- emmeans::emmeans(
     model,
     specs = cleaned_terms,
@@ -116,8 +134,6 @@
 
 
 
-
-
 .ggemmeans_predict_generic <- function(model, data_grid, cleaned_terms, ci.lvl, pmode, type, interval = NULL, model_data = NULL, ...) {
 
   tmp <- tryCatch(
@@ -169,8 +185,6 @@
 
 
 
-
-
 .ggemmeans_predict_nlme <- function(model, data_grid, cleaned_terms, ci.lvl, type, interval = NULL, model_data = NULL, ...) {
 
   tmp <- tryCatch(
