@@ -1,4 +1,4 @@
-get_predictions_lm <- function(model, fitfram, ci.lvl, model_class, value_adjustment, terms, vcov.fun, vcov.type, vcov.args, condition, interval, ...) {
+get_predictions_lm <- function(model, fitfram, ci.lvl, model_class, value_adjustment, terms, vcov.fun, vcov.type, vcov.args, condition, interval, type, ...) {
   # does user want standard errors?
   se <- !is.null(ci.lvl) && !is.na(ci.lvl) && is.null(vcov.fun)
 
@@ -6,7 +6,7 @@ get_predictions_lm <- function(model, fitfram, ci.lvl, model_class, value_adjust
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
     ci <- (1 + ci.lvl) / 2
   else
-    ci <- .975
+    ci <- 0.975
 
   prdat <-
     stats::predict(
@@ -17,8 +17,14 @@ get_predictions_lm <- function(model, fitfram, ci.lvl, model_class, value_adjust
       ...
     )
 
-  # did user request standard errors? if yes, compute CI
-  if (!is.null(vcov.fun) || (!is.null(interval) && interval == "prediction")) {
+  if (type == "sim") {
+
+    # simulate predictions
+    fitfram <- .do_simulate(model, terms, ci, ...)
+
+  } else if (!is.null(vcov.fun) || (!is.null(interval) && interval == "prediction")) {
+
+    # did user request standard errors? if yes, compute CI
 
     # copy predictions
     if ("fit" %in% names(prdat))
@@ -39,7 +45,7 @@ get_predictions_lm <- function(model, fitfram, ci.lvl, model_class, value_adjust
       interval = interval
     )
 
-    if (!is.null(se.pred)) {
+    if (.check_returned_se(se.pred)) {
       se.fit <- se.pred$se.fit
       fitfram <- se.pred$prediction_data
 
