@@ -1,8 +1,6 @@
 get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd, terms = NULL, ...) {
   # check if pkg is available
-  if (!requireNamespace("rstantools", quietly = TRUE)) {
-    stop("Package `rstantools` is required to compute predictions.", call. = FALSE)
-  }
+  insight::check_if_installed("rstantools")
 
   # does user want standard errors?
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
@@ -21,7 +19,7 @@ get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd,
 
   if (!is.null(terms)) {
     mf <- insight::get_data(model)
-    vo <- names(which(sapply(mf, is.ordered)))
+    vo <- names(which(vapply(mf, is.ordered, logical(1))))
     fac2ord <- which(terms %in% vo)
 
     if (!.is_empty(fac2ord)) {
@@ -139,7 +137,7 @@ get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd,
 
   } else {
     # compute median, as "most probable estimate"
-    fitfram$predicted <- sapply(prdat, stats::median)
+    fitfram$predicted <- vapply(prdat, stats::median, numeric(1))
   }
 
 
@@ -153,7 +151,7 @@ get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd,
 
     if (inherits(prdat2, "array")) {
       if (length(dim(prdat2)) == 3) {
-        tmp <- do.call(rbind, lapply(1:dim(prdat2)[3], function(.x) {
+        tmp <- do.call(rbind, lapply(seq_len(dim(prdat2)[3]), function(.x) {
           as.data.frame(rstantools::predictive_interval(as.matrix(prdat2[, , .x]), prob = ci.lvl))
         }))
       } else {
