@@ -6,11 +6,9 @@ get_predictions_survival <- function(model, fitfram, ci.lvl, type, terms, ...) {
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
     ci <- (1 + ci.lvl) / 2
   else
-    ci <- .975
+    ci <- 0.975
 
-  if (!requireNamespace("survival", quietly = TRUE)) {
-    stop("Package `survival` required. Please install it.", call. = FALSE)
-  }
+  insight::check_if_installed("survival")
 
   # get survial probabilities and cumulative hazards
 
@@ -22,7 +20,7 @@ get_predictions_survival <- function(model, fitfram, ci.lvl, type, terms, ...) {
     ...
   )
 
-  # check what user requested and either returnd surv probs
+  # check what user requested and either return surv probs
   # or cumulative hazards, including CI
 
   if (type == "surv") {
@@ -46,7 +44,7 @@ get_predictions_survival <- function(model, fitfram, ci.lvl, type, terms, ...) {
   clean_terms <- .clean_terms(terms)
   ff <- fitfram[clean_terms]
 
-  do.call(rbind, lapply(seq_len(nrow(ff)), function(i) {
+  out <- do.call(rbind, lapply(seq_len(nrow(ff)), function(i) {
     dat <- data.frame(
       time = prdat$time,
       predicted = pr[, i],
@@ -60,4 +58,23 @@ get_predictions_survival <- function(model, fitfram, ci.lvl, type, terms, ...) {
 
     cbind(dat[, 1, drop = FALSE], dat2, dat[, 2:4])
   }))
+
+  if (min(out$time, na.rm = TRUE) > 1) {
+    time <- 1
+    predicted <- as.numeric(type == "surv")
+    conf.low <- as.numeric(type == "surv")
+    conf.high <- as.numeric(type == "surv")
+
+    dat <- expand.grid(lapply(out[clean_terms], unique))
+    names(dat) <- clean_terms
+
+    out <- rbind(
+      out,
+      cbind(time = 1, dat, predicted = predicted,
+            conf.low = conf.low, conf.high = conf.high)
+    )
+  }
+
+  # sanity check - don't return NA
+  out[stats::complete.cases(out), ]
 }
