@@ -6,7 +6,7 @@ get_predictions_wbm <- function(model, fitfram, ci.lvl, linv, type, terms, condi
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
     ci <- (1 + ci.lvl) / 2
   else
-    ci <- .975
+    ci <- 0.975
 
   # check whether predictions should be conditioned
   # on random effects (grouping level) or not.
@@ -15,18 +15,10 @@ get_predictions_wbm <- function(model, fitfram, ci.lvl, linv, type, terms, condi
   else
     ref <- NULL
 
-  clean_terms <- .clean_terms(terms)
-
   if (type == "sim") {
 
-    add.args <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
-
-    if ("nsim" %in% names(add.args))
-      nsim <- eval(add.args[["nsim"]])
-    else
-      nsim <- 1000
-
-    fitfram <- simulate_predictions(model, nsim, clean_terms, ci)
+    # simulate predictions
+    fitfram <- .do_simulate(model, terms, ci, ...)
 
   } else {
 
