@@ -1,6 +1,3 @@
-#' @importFrom stats confint na.omit
-#' @importFrom sjlabelled get_labels as_numeric
-#' @importFrom insight find_response get_data model_info
 #' @rdname ggpredict
 #' @export
 ggemmeans <- function(model,
@@ -12,13 +9,13 @@ ggemmeans <- function(model,
                       back.transform = TRUE,
                       interval = "confidence",
                       ...) {
-
-  if (!requireNamespace("emmeans")) {
-    stop("Package `emmeans` required to compute marginal effects with `ggemmeans()`.", call. = FALSE)
-  }
-
+  insight::check_if_installed("emmeans")
   # check arguments
-  type <- match.arg(type, choices = c("fe", "fixed", "count", "re", "random", "fe.zi", "zero_inflated", "re.zi", "zi_random", "zero_inflated_random", "zi.prob", "zi_prob"))
+  type <- match.arg(
+    type,
+    choices = c("fe", "fixed", "count", "re", "random", "fe.zi", "zero_inflated",
+                "re.zi", "zi_random", "zero_inflated_random", "zi.prob", "zi_prob")
+  )
   interval <- match.arg(interval, choices = c("confidence", "prediction"))
   model_name <- deparse(substitute(model))
 
@@ -33,7 +30,7 @@ ggemmeans <- function(model,
     "zero_inflated_random" = "re.zi",
     "zi_prob" = "zi.prob",
     "survival" = "surv",
-    "cumulative_hazard" = "cumhaz"    ,
+    "cumulative_hazard" = "cumhaz",
     type
   )
 
@@ -42,8 +39,15 @@ ggemmeans <- function(model,
     terms <- all.vars(terms)
   }
 
+  # tidymodels?
+  if (inherits(model, "model_fit")) {
+    model <- model$fit
+  }
+
   if (inherits(model, c("glmmTMB", "MixMod")) && type == "zi.prob") {
-    stop(sprintf("This prediction-type is currently not available for models of class '%s'.", class(model)[1]), call. = FALSE)
+    insight::format_error(sprintf(
+      "This prediction-type is currently not available for models of class '%s'.", class(model)[1]
+    ))
   }
 
   # for gamm/gamm4 objects, we have a list with two items, mer and gam
@@ -125,7 +129,7 @@ ggemmeans <- function(model,
 
   # apply link inverse function
   linv <- insight::link_inverse(model)
-  if (!is.null(linv) && (inherits(model, "lrm") || pmode == "link" || (inherits(model, "MixMod") && type != "fe.zi"))) {
+  if (!is.null(linv) && (inherits(model, c("lrm", "orm")) || pmode == "link" || (inherits(model, "MixMod") && type != "fe.zi"))) {
     result$predicted <- linv(result$predicted)
     result$conf.low <- linv(result$conf.low)
     result$conf.high <- linv(result$conf.high)
@@ -150,10 +154,7 @@ ggemmeans <- function(model,
     model_info = model_info,
     type = type,
     prediction.interval = attr(prediction_data, "prediction.interval", exact = TRUE),
-    at_list = .data_grid(
-      model = model, model_frame = original_model_frame, terms = terms, value_adjustment = typical,
-      condition = condition, show_pretty_message = FALSE, emmeans.only = TRUE
-    ),
+    at_list = data_grid,
     ci.lvl = ci.lvl
   )
 }
@@ -162,7 +163,7 @@ ggemmeans <- function(model,
 .get_prediction_mode_argument <- function(model, model_info, type) {
   if (inherits(model, "betareg"))
     "response"
-  else if (inherits(model, c("polr", "clm", "clmm", "clm2", "rms")))
+  else if (inherits(model, c("polr", "clm", "clmm", "clm2", "rms", "lrm", "orm")))
     "prob"
   else if (inherits(model, "lmerMod"))
     "asymptotic"
