@@ -3,12 +3,12 @@
 #'
 #' @description Create a data frame for the "newdata"-argument that contains
 #'   all combinations of values from the terms in questions. Similar to
-#'   \code{\link{expand.grid}}. The \code{terms}-argument accepts all shortcuts
-#'   for representative values as in \code{ggpredict()}.
+#'   `expand.grid()`. The `terms`-argument accepts all shortcuts
+#'   for representative values as in `ggpredict()`.
 #'
 #' @param model A fitted model object.
 #' @param terms Character vector with the names of those terms from
-#'   \code{model} for which all combinations of values should be created.
+#'   `model` for which all combinations of values should be created.
 #'
 #' @inheritParams ggpredict
 #'
@@ -30,14 +30,18 @@
 #'
 #' @export
 new_data <- function(model, terms, typical = "mean", condition = NULL) {
-  .get_data_grid(
+  .data_grid(
     model = model,
-    mf = insight::get_data(model),
+    model_frame = insight::get_data(model),
     terms = terms,
-    typ.fun = typical,
-    fac.typical = TRUE,
-    pretty.message = TRUE,
+    value_adjustment = typical,
+    factor_adjustment = TRUE,
+    show_pretty_message = TRUE,
     condition = condition,
     emmeans.only = FALSE
   )
 }
+
+#' @rdname new_data
+#' @export
+data_grid <- new_data
