@@ -29,16 +29,16 @@
         interval
       )
     },
-    error = function(x) { x },
-    warning = function(x) { NULL },
-    finally = function(x) { NULL }
+    error = function(x) x,
+    warning = function(x) NULL,
+    finally = function(x) NULL
   )
 
   if (is.null(se) || inherits(se, c("error", "simpleError"))) {
     insight::print_color("Error: Confidence intervals could not be computed.\n", "red")
     if (inherits(se, c("error", "simpleError"))) {
-      cat(sprintf("* Reason: %s\n", .safe_deparse(se[[1]])))
-      err.source <- .safe_deparse(se[[2]])
+      cat(sprintf("* Reason: %s\n", insight::safe_deparse(se[[1]])))
+      err.source <- insight::safe_deparse(se[[2]])
       if (all(grepl("^(?!(safe_se_from_vcov))", err.source, perl = TRUE))) {
         cat(sprintf("* Source: %s\n", err.source))
       }
@@ -49,6 +49,7 @@
   se
 }
 
+
 .safe_se_from_vcov <- function(model,
                               prediction_data,
                               value_adjustment,
@@ -76,7 +77,7 @@
 
   if (!is.null(condition)) {
     cn <- names(condition)
-    cn.factors <- sapply(cn, function(.x) is.factor(model_frame[[.x]]) && !(.x %in% re.terms))
+    cn.factors <- vapply(cn, function(.x) is.factor(model_frame[[.x]]) && !(.x %in% re.terms), logical(1))
     condition <- condition[!cn.factors]
     if (.is_empty(condition)) condition <- NULL
   }
@@ -181,7 +182,7 @@
     if (!is.null(model_class) && model_class %in% c("polr", "multinom", "mixor")) {
       se.fit <- rep(se.fit, each = .n_distinct(prediction_data$response.level))
     } else if (type == "re" && n_se < n_pred && n_pred %% n_se == 0) {
-      se.fit <- rep(se.fit, times = n_pred / n_se)
+      se.fit <- rep(se.fit, each = n_pred / n_se)
     } else {
       se.fit <- se.fit[1:n_pred]
     }
