@@ -1,4 +1,3 @@
-#' @importFrom insight find_terms
 .back_transform_response <- function(model, mydf, back.transform) {
   # check if outcome is log-transformed, and if so,
   # back-transform predicted values to response scale
@@ -24,7 +23,7 @@
         }
       }
 
-      message("Model has log-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the log-scale.")
+      message(insight::format_message("Model has log-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the log-scale."))
     } else {
       message("Model has log-transformed response. Predictions are on log-scale.")
     }
@@ -37,7 +36,7 @@
         mydf$conf.low <- expm1(mydf$conf.low)
         mydf$conf.high <- expm1(mydf$conf.high)
       }
-      message("Model has log-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the log-scale.")
+      message(insight::format_message("Model has log-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the log-scale."))
     } else {
       message("Model has log-transformed response. Predictions are on log(mu + 1) scale.")
     }
@@ -52,7 +51,7 @@
         mydf$conf.low <- mydf$conf.low^2 - plus_minus
         mydf$conf.high <- mydf$conf.high^2 - plus_minus
       }
-      message("Model has sqrt-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the sqrt-scale.")
+      message(insight::format_message("Model has sqrt-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the sqrt-scale."))
     } else {
       message("Model has sqrt-transformed response. Predictions are on sqrt-scale.")
     }
