@@ -1,12 +1,9 @@
 if (suppressWarnings(
-  require("testthat") &&
-  require("ggeffects") &&
-  require("sjmisc") &&
-  require("robustbase")
+  requiet("testthat") &&
+  requiet("ggeffects") &&
+  requiet("sjmisc") &&
+  requiet("robustbase")
 )) {
-
-  context("ggeffects, glmrob")
-
   data(efc)
   efc$neg_c_7d <- dicho(efc$neg_c_7)
   m1 <- glmrob(neg_c_7d ~ c12hour + e42dep + c161sex + c172code, data = efc, family = binomial)
