@@ -1,11 +1,9 @@
 if (suppressWarnings(
-  require("testthat") &&
-  require("ggeffects") &&
-  require("sjlabelled") &&
-  require("sjmisc")
+  requiet("testthat") &&
+  requiet("ggeffects") &&
+  requiet("sjlabelled") &&
+  requiet("sjmisc")
 )) {
-  context("ggeffects, plot")
-
   # lm, linear regression ----
 
   data(efc)
@@ -17,8 +15,8 @@ if (suppressWarnings(
     p <- plot(pr)
     p <- plot(pr, ci = FALSE)
     p <- plot(pr, ci = TRUE, ci.style = "dot")
-    p <- plot(pr, rawdata = TRUE)
-    p <- plot(pr, rawdata = TRUE, jitter = FALSE)
+    p <- plot(pr, add.data = TRUE)
+    p <- plot(pr, add.data = TRUE, jitter = FALSE)
     p <- plot(pr, colors = "bw")
     p <- plot(pr, colors = "gs")
 
@@ -26,8 +24,8 @@ if (suppressWarnings(
     p <- plot(pr)
     p <- plot(pr, ci = FALSE)
     p <- plot(pr, ci = TRUE, ci.style = "dot")
-    p <- plot(pr, rawdata = TRUE)
-    p <- plot(pr, rawdata = TRUE, jitter = 0)
+    p <- plot(pr, add.data = TRUE)
+    p <- plot(pr, add.data = TRUE, jitter = 0)
     p <- plot(pr, facets = TRUE)
     p <- plot(pr, facets = FALSE)
     p <- plot(pr, use.theme = FALSE)
